@@ -147,7 +147,9 @@ def main():
         + ". \nOk?"
     )
 
-    with multiprocessing.Pool(_CPUS) as pool:
+    breakpoint()
+
+    with multiprocessing.Pool(_CPUS[0]) as pool:
         pool.map_async(spin_up, folders).get()
 
 if __name__ == "__main__":
